@@ -2,6 +2,7 @@ import pytest
 
 from pdfdancer.pdfdancer_v1 import PDFDancer
 from tests.e2e import _require_env_and_fixture
+from tests.e2e.pdf_assertions import PDFAssertions
 
 
 def test_find_lines_by_position():
@@ -37,7 +38,7 @@ def test_find_lines_by_text():
         assert pytest.approx(line.position.y(), rel=0, abs=2) == 606
 
 
-def test_delete_line(tmp_path):
+def test_delete_line():
     base_url, token, pdf_path = _require_env_and_fixture("ObviouslyAwesome.pdf")
 
     with PDFDancer.open(pdf_path, token=token, base_url=base_url, timeout=30.0) as pdf:
@@ -45,39 +46,48 @@ def test_delete_line(tmp_path):
         line.delete()
         assert pdf.page(0).select_text_lines_starting_with("The Complete") == []
 
-        out = tmp_path / "deleteLine.pdf"
-        pdf.save(out)
-        assert out.exists() and out.stat().st_size > 0
+    (
+        PDFAssertions(pdf)
+        .assert_textline_does_not_exist("The Complete")
+    )
 
 
-def test_move_line(tmp_path):
+def test_move_line():
     base_url, token, pdf_path = _require_env_and_fixture("ObviouslyAwesome.pdf")
 
+    new_x = None
+    new_y = None
     with PDFDancer.open(pdf_path, token=token, base_url=base_url, timeout=30.0) as pdf:
         line = pdf.page(0).select_text_lines_starting_with("The Complete")[0]
         pos = line.position
-        line.move_to(pos.x() + 100, pos.y())
+        new_x = pos.x() + 100
+        new_y = pos.y() + 18
+        line.move_to(new_x, new_y)
 
-        moved_para = pdf.page(0).select_paragraphs_at(pos.x() + 100, pos.y())[0]
+        moved_para = pdf.page(0).select_paragraphs_at(new_x, new_y)[0]
         assert moved_para is not None
 
-        out = tmp_path / "moveLine.pdf"
-        pdf.save(out)
-        assert out.exists() and out.stat().st_size > 0
+    (
+        PDFAssertions(pdf)
+        .assert_textline_is_at("The Complete", new_x, new_y)
+    )
 
 
-def test_modify_line(tmp_path):
+def test_modify_line():
     base_url, token, pdf_path = _require_env_and_fixture("ObviouslyAwesome.pdf")
 
     with PDFDancer.open(pdf_path, token=token, base_url=base_url, timeout=30.0) as pdf:
         line = pdf.page(0).select_text_lines_starting_with("The Complete")[0]
         line.edit().replace(" replaced ").apply()
 
-        out = tmp_path / "modifyLine.pdf"
-        pdf.save(out)
-        assert out.exists() and out.stat().st_size > 0
-
         # Validate replacements
         assert pdf.page(0).select_text_lines_starting_with("The Complete") == []
         assert pdf.page(0).select_text_lines_starting_with(" replaced ") != []
         assert pdf.page(0).select_paragraphs_starting_with(" replaced ") != []
+
+    (
+        PDFAssertions(pdf)
+        .assert_textline_does_not_exist("The Complete")
+        .assert_textline_exists(" replaced ")
+        .assert_paragraph_exists(" replaced ")
+    )
